%% Fault model plotting
% This file generates the plots for \subsection{Fault modeling} for the
% paper submitted to AIAA SciTech 2015.

%% Clean up
close all
bdclose all
clc

%% Set variables of the nonlinear and linear responses
SIL_mod_1 = simres_NL_Ftp_cz;
SIL_mod_2 = simres_NL_Fbp_cz;
Lin_mod = simres_L_Uf_cz;
r2d = 180/pi;

%% Check that the files loaded are correct
SIL_mod_1.siminfo
SIL_mod_2.siminfo
Lin_mod.siminfo

if ~strcmp(SIL_mod_1.siminfo(1:7), 'SIL_sim')
    error('The model loaded into SIL_mod_1 is not from the SIL_sim.');
end
if ~strcmp(SIL_mod_2.siminfo(1:7), 'SIL_sim')
    error('The model loaded into SIL_mod_2 is not from the SIL_sim.');
end
if ~strcmp(Lin_mod.siminfo(1:7), 'Lin_sim')
    error('The model loaded into Lin_mod is not from the Lin_sim.');
end

%% Fault injection time marker
fault.time = [5; 5];
fault.ycoord = [-1e3, 1e3];

%% Plot responses of outputs and control commands
figure;

subplot(3,2,1); % beta
hold on;
plot(fault.time, fault.ycoord, 'k--', 'LineWidth', 2.5);
f1 = plot(SIL_mod_1.time, SIL_mod_1.beta*r2d);
set(f1, 'LineStyle', '-', 'Color', 'k', 'LineWidth', 2.5);
hold off;
grid on;
ylabel('\beta [deg]', 'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 40], 'YLim', [-5 10], ...
        'XTickLabel', [], 'YTick', -5:5:10, 'FontSize', 14, 'FontWeight', 'bold');

subplot(3,2,3); % phi
hold on;
plot(fault.time, fault.ycoord, 'k--', 'LineWidth', 2.5);
f1 = plot(SIL_mod_1.time, SIL_mod_1.phi*r2d);
set(f1, 'LineStyle', '-', 'Color', 'k', 'LineWidth', 2.5);
hold off;
grid on;
ylabel('\phi [deg]', 'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 40], 'YLim', [-5 10], ...
        'XTickLabel', [], 'YTick', -5:5:10, 'FontSize', 14, 'FontWeight', 'bold');

subplot(3,2,5); % psi
hold on;
plot(fault.time, fault.ycoord, 'k--', 'LineWidth', 2.5);
f1 = plot(SIL_mod_1.time, SIL_mod_1.psi*r2d);
set(f1, 'LineStyle', '-', 'Color', 'k', 'LineWidth', 2.5);
hold off;
grid on;
xlabel('Time, t [s]', 'FontSize', 14, 'FontWeight', 'bold');
ylabel('\psi [deg]', 'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 40], 'YLim', [145 160], ...
        'YTick', 145:5:160, 'FontSize', 14, 'FontWeight', 'bold');

subplot(3,2,2); % p and r
hold on;
plot(fault.time, fault.ycoord, 'k--', 'LineWidth', 2.5);
f1 = plot(SIL_mod_1.time, SIL_mod_1.p*r2d);
set(f1, 'LineStyle', '-', 'Color', 'b', 'LineWidth', 2.5);
f2 = plot(SIL_mod_1.time, SIL_mod_1.r*r2d);
set(f2, 'LineStyle', '--', 'Color', 'g', 'LineWidth', 2.5);
hold off;
grid on;
ylabel('p, r [deg/s]', 'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 40], 'YLim', [-20 20], ...
        'XTickLabel', [], 'YTick', -20:10:20, 'FontSize', 14, 'FontWeight', 'bold');
h1 = legend([f1, f2], 'p', 'r', 'Location', 'Best');
set(h1, 'FontSize', 14, 'FontWeight', 'bold');

subplot(3,2,4); % rudder
hold on;
plot(fault.time, fault.ycoord, 'k--', 'LineWidth', 2.5);
f1 = plot(SIL_mod_1.time, SIL_mod_1.rudder*r2d);
set(f1, 'LineStyle', '-', 'Color', 'b', 'LineWidth', 2.5);
f2 = plot(SIL_mod_1.time, SIL_mod_1.t_rudder*r2d);
set(f2, 'LineStyle', '--', 'Color', 'g', 'LineWidth', 2.5);
hold off;
grid on;
ylabel( '\delta_{rud,cmd}, \delta_{rud}^t [deg]', ...
        'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 40], 'YLim', [-30 30], ...
        'XTickLabel', [], 'YTick', -30:10:30, 'FontSize', 14, 'FontWeight', 'bold');
h1 = legend([f1, f2], '\delta_{rud,cmd}', '\delta_{rud}^t', 'Location', 'Best');
set(h1, 'FontSize', 14, 'FontWeight', 'bold');

subplot(3,2,6); % aileron
hold on;
plot(fault.time, fault.ycoord, 'k--', 'LineWidth', 2.5);
f1 = plot(SIL_mod_1.time, SIL_mod_1.r_aileron*r2d);
set(f1, 'LineStyle', '-', 'Color', 'k', 'LineWidth', 2.5);
hold off;
grid on;
xlabel('Time, t [s]', 'FontSize', 14, 'FontWeight', 'bold');
ylabel('\delta_{ail,cmd}^r [deg]', 'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 40], 'YLim', [-3 1], ...
        'YTick', -3:1:1, 'FontSize', 14, 'FontWeight', 'bold');

figure; % aileron for top and bottom rudder faults
hold on;
plot(fault.time, fault.ycoord, 'k--', 'LineWidth', 2.5);
f1 = plot(SIL_mod_1.time, SIL_mod_1.r_aileron*r2d, ...
        SIL_mod_2.time, SIL_mod_2.r_aileron*r2d, ...
        Lin_mod.time_L, Lin_mod.r_aileron_L + Lin_mod.TrimCondition.Inputs.CtrlSurf(4)*r2d);
set(f1(1), 'LineStyle', '-.', 'Color', 'b', 'LineWidth', 2.5);
set(f1(2), 'LineStyle', '--', 'Color', 'r', 'LineWidth', 2.5);
set(f1(3), 'LineStyle', '-', 'Color', 'g', 'LineWidth', 2.5);
hold off;
grid on;
xlabel('Time, t [s]', 'FontSize', 14, 'FontWeight', 'bold');
ylabel('\delta_{ail,cmd}^r [deg]', 'FontSize', 14, 'FontWeight', 'bold');
a1 = gca;
set(a1, 'XMinorTick', 'on', 'YMinorTick', 'on', ...
        'XLim', [0 40], 'YLim', [-3 1], ...
        'YTick', -3:1:1, 'FontSize', 14, 'FontWeight', 'bold');
h1 = legend(f1, ...
        'Fault: \delta_{rud}^t = +25deg', 'Fault: \delta_{rud}^b = +25deg', 'No fault', 'Location', 'Best');
set(h1, 'FontSize', 14, 'FontWeight', 'bold');
