%% setup.m
% UAV Linear Simulation setup
%
% This script will setup the linear simulation. This script first calls the
% setup file associated with the NL_sim directory.
%
% University of Minnesota
% Aerospace Engineering and Mechanics
% Copyright 2011 Regents of the University of Minnesota.
% All rights reserved.
%
% SVN Info: ID not available

%% Clean up
clear all
close all
bdclose all
clc

% %% Run the NL_sim setup
% run('..\NL_sim\setup.m');
% addpath ../Controllers

%% Add Libraries and controllers folder to MATLAB path
addpath ../Libraries
addpath ../Controllers

%% Load airframe configuration and trim condition
% To change these, use the functions "UAV_config.m" and "trim_UAV.m"
load UAV_modelconfig
load UAV_trimcondition
load UAV_linearmodel

%% Simulation sample time
SampleTime = 0.02; %sec

%% Integer Time delay in flight software loop
IntegerTimeDelay = 2; % .04sec

%% Set controller variants
% Each variant corresponds to a different Simulink model that will be
% referenced in the "UAV_Lin/Control Software/Control Software" block.
baseline_control_var = Simulink.Variant('controller_mode == 1');
heading_control_var = Simulink.Variant('controller_mode == 2');
student_control_var = Simulink.Variant('controller_mode == 3');
lqr_control_var = Simulink.Variant('controller_mode == 4');
heading_control_zero_aos_var = Simulink.Variant('controller_mode == 41');
% The heading_control_zero_aos is the modified controller which tracks
% sideslip angle as well as the yaw rate.

%% Set controller mode
% Use this variable to quickly change what controller is used in the
% simulation.
%
% 1 = baseline controller (Simulink)
% 2 = Heading controller (Simulink)
% 3 = Student controller (Simulink)     
% 4 = LQR controller (Simulink)
% 41 = Heading controller with zero aos (Simulink)
controller_mode = 41;

% Load controller parameters or compile flight code
switch controller_mode
    case 1 %Basleine controller in Simulink
        baseline_gains;   % Declare baseline controller gains
        pitch_gains = [kp_PT, ki_PT, kp_PD];
        roll_gains = [kp_RT, ki_RT, kp_RD];
        yaw_damper_num = [YDz_num]; % discrete transfer function yaw damper coefficients
        yaw_damper_den = [YDz_den];
        
    case 2 %Heading controller in Simulink
        baseline_gains;  % heading controller lays on top of the baseline controller        
        pitch_gains = [kp_PT, ki_PT, kp_PD];
        roll_gains = [kp_RT, ki_RT, kp_RD];
        yaw_damper_num = [YDz_num]; % discrete transfer function yaw damper coefficients
        yaw_damper_den = [YDz_den];
        
        heading_gains;  % Specify waypoint gains
        phi_sat = 45;   % phi cotnroller output saturation
        theta_sat = 20; % altitude controller output saturation
        
    case 3 %Student controller in Simulink
        % Specify gains here
        
    case 4 % LQR controller in Simulink
        % Parameters defined here are identical to those in lqr_control.c
        K_pitch = [-0.240144526553189,  0.079132432193614, 0.287138908852059];
        K_roll = [-0.6679,   0.0243,   0.0251,   0.3631;...
            -0.1355,   0.0004,   0.0284,   0.0710];
        
    case 41 % Heading controller with zero aos in Simulink
        baseline_gains;  % heading controller lays on top of the baseline controller        
        pitch_gains = [kp_PT, ki_PT, kp_PD];
        roll_gains = [kp_RT, ki_RT, kp_RD];
        yaw_gains = [kp_YT, ki_YT, kp_YD]; % new gains added for the PI controller that tracks beta and r
        yaw_damper_num = [YDz_num]; % discrete transfer function yaw damper coefficients
        yaw_damper_den = [YDz_den];
        
        heading_gains;  % Specify heading gains
        phi_sat = 45;   % phi cotnroller output saturation
        theta_sat = 20; % altitude controller output saturation

end

%% Open UAV_Lin model
UAV_Lin